@@ -13,7 +13,7 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 
-   */
+ */
 
 #include "collectionDB.h"
 
@@ -22,17 +22,24 @@
 #include <QUuid>
 #include <QDateTime>
 
-#include <MauiKit3/Core/fmh.h>
-#include <MauiKit3/FileBrowsing/fmstatic.h>
+#include <MauiKit4/Core/fmh.h>
+#include <MauiKit4/FileBrowsing/fmstatic.h>
 
 using namespace BAE;
 
-CollectionDB::CollectionDB(QObject *parent)
-    : QObject(parent)
+Q_GLOBAL_STATIC(CollectionDB, collectionInstance)
+
+CollectionDB *CollectionDB::getInstance()
+{
+    return collectionInstance();
+}
+
+CollectionDB::CollectionDB(QObject *parent) : QObject(parent)
 {
     this->name = QUuid::createUuid().toString();
 
-    if (!FMH::fileExists(QUrl::fromUserInput(BAE::CollectionDBPath + BAE::DBName))) {
+    if (!FMH::fileExists(QUrl::fromUserInput(BAE::CollectionDBPath + BAE::DBName)))
+    {
         QDir collectionDBPath_dir(BAE::CollectionDBPath);
         if (!collectionDBPath_dir.exists())
             collectionDBPath_dir.mkpath(".");
@@ -41,8 +48,10 @@ CollectionDB::CollectionDB(QObject *parent)
         qDebug() << "Collection doesn't exists, trying to create it" << BAE::CollectionDBPath + BAE::DBName;
         this->prepareCollectionDB();
 
-    } else
+    } else        
+    {
         this->openDB(this->name);
+    }
 }
 
 void CollectionDB::prepareCollectionDB()
@@ -52,14 +61,16 @@ void CollectionDB::prepareCollectionDB()
     QFile file(":/db/script.sql");
     qDebug() << file.exists();
 
-    if (!file.exists()) {
+    if (!file.exists())
+    {
         QString log = QStringLiteral("Fatal error on build database. The file '");
         log.append(file.fileName() + QStringLiteral("' for database and tables creation query cannot be not found!"));
         qDebug() << log;
         return;
     }
 
-    if (!file.open(QIODevice::ReadOnly)) {
+    if (!file.open(QIODevice::ReadOnly))
+    {
         qDebug() << QStringLiteral("Fatal error on try to create database! The file with sql queries for database creation cannot be opened!");
         return;
     }
@@ -70,7 +81,8 @@ void CollectionDB::prepareCollectionDB()
     QString cleanedLine;
     QStringList strings;
 
-    while (!file.atEnd()) {
+    while (!file.atEnd())
+    {
         hasText = false;
         line = "";
         readLine = "";
@@ -104,7 +116,8 @@ bool CollectionDB::check_existance(const QString &tableName, const QString &sear
     auto queryStr = QString("SELECT %1 FROM %2 WHERE %3 = \"%4\"").arg(searchId, tableName, searchId, search);
     auto query = this->getQuery(queryStr);
 
-    if (!query.exec()) {
+    if (!query.exec())
+    {
         qDebug() << query.lastError().text();
         return false;
     }
@@ -117,11 +130,13 @@ bool CollectionDB::check_existance(const QString &tableName, const QString &sear
 
 bool CollectionDB::insert(const QString &tableName, const QVariantMap &insertData)
 {
-    if (tableName.isEmpty()) {
+    if (tableName.isEmpty())
+    {
         qDebug() << QStringLiteral("Fatal error on insert! The table name is empty!");
         return false;
 
-    } else if (insertData.isEmpty()) {
+    } else if (insertData.isEmpty())
+    {
         qDebug() << QStringLiteral("Fatal error on insert! The insertData is empty!");
         return false;
     }
@@ -138,7 +153,7 @@ bool CollectionDB::insert(const QString &tableName, const QVariantMap &insertDat
     query.prepare(sqlQueryString);
 
     int k = 0;
-    foreach (const QVariant &value, values)
+    for (const QVariant &value : values)
         query.bindValue(k++, value);
 
     return query.exec();
@@ -146,10 +161,12 @@ bool CollectionDB::insert(const QString &tableName, const QVariantMap &insertDat
 
 bool CollectionDB::update(const QString &tableName, const FMH::MODEL &updateData, const QVariantMap &where)
 {
-    if (tableName.isEmpty()) {
+    if (tableName.isEmpty())
+    {
         qDebug() << QStringLiteral("Fatal error on insert! The table name is empty!");
         return false;
-    } else if (updateData.isEmpty()) {
+    } else if (updateData.isEmpty())
+    {
         qDebug() << QStringLiteral("Fatal error on insert! The insertData is empty!");
         return false;
     }
@@ -209,12 +226,14 @@ bool CollectionDB::execQuery(const QString &queryTxt)
 
 void CollectionDB::openDB(const QString &name)
 {
-    if (!QSqlDatabase::contains(name)) {
+    if (!QSqlDatabase::contains(name))
+    {
         this->m_db = QSqlDatabase::addDatabase(QStringLiteral("QSQLITE"), name);
         this->m_db.setDatabaseName(BAE::CollectionDBPath + BAE::DBName);
     }
 
-    if (!this->m_db.isOpen()) {
+    if (!this->m_db.isOpen())
+    {
         if (!this->m_db.open())
             qDebug() << "ERROR OPENING DB" << this->m_db.lastError().text() << m_db.connectionName();
         else {
@@ -230,7 +249,8 @@ bool CollectionDB::addTrack(const FMH::MODEL &track)
         return false;
 
     const auto url = track[FMH::MODEL_KEY::URL];
-    if (check_existance(TABLEMAP[BAE::TABLE::TRACKS], BAE::KEYMAP[BAE::KEY::URL], url)) {
+    if (check_existance(TABLEMAP[BAE::TABLE::TRACKS], BAE::KEYMAP[BAE::KEY::URL], url))
+    {
         return false;
     }
 
@@ -346,9 +366,9 @@ bool CollectionDB::albumTrack(const FMH::MODEL &track, const QString &value)
     if (!insert(TABLEMAP[TABLE::ALBUMS], albumMap))
         return false;
 
-    // update albums SET album = "newalbumname" WHERE album = "albumname" NAD artist = "aretist name";
+           // update albums SET album = "newalbumname" WHERE album = "albumname" NAD artist = "aretist name";
     queryTxt = QString("UPDATE %1 SET %2 = %3 AND %4 = %5 WHERE %2 = %6 AND %4 = %5")
-            .arg(TABLEMAP[TABLE::TRACKS], FMH::MODEL_NAME[FMH::MODEL_KEY::ALBUM], value, FMH::MODEL_NAME[FMH::MODEL_KEY::ARTIST], oldAlbum[FMH::MODEL_KEY::ARTIST], oldAlbum[FMH::MODEL_KEY::ALBUM]);
+                   .arg(TABLEMAP[TABLE::TRACKS], FMH::MODEL_NAME[FMH::MODEL_KEY::ALBUM], value, FMH::MODEL_NAME[FMH::MODEL_KEY::ARTIST], oldAlbum[FMH::MODEL_KEY::ARTIST], oldAlbum[FMH::MODEL_KEY::ALBUM]);
     auto query = this->getQuery(queryTxt);
 
     if (!execQuery(query))
@@ -371,7 +391,7 @@ bool CollectionDB::playedTrack(const QString &url)
 
     if (query.exec())
     {
-//        query.clar();
+        //        query.clar();
         auto query2 = getQuery();
 
         query2.prepare("UPDATE TRACKS SET lastsync = :date WHERE url = :url");
@@ -436,7 +456,7 @@ FMH::MODEL_LIST CollectionDB::getDBData(const QString &queryTxt, std::function<b
 FMH::MODEL_LIST CollectionDB::getAlbumTracks(const QString &album, const QString &artist, const FMH::MODEL_KEY &orderBy, const BAE::W &order)
 {
     const auto queryTxt = QString("SELECT * FROM %1 WHERE %2 = \"%3\" AND %4 = \"%5\" ORDER by %6 %7")
-            .arg(TABLEMAP[TABLE::TRACKS], FMH::MODEL_NAME[FMH::MODEL_KEY::ARTIST], artist, FMH::MODEL_NAME[FMH::MODEL_KEY::ALBUM], album, FMH::MODEL_NAME[orderBy], SLANG[order]);
+                              .arg(TABLEMAP[TABLE::TRACKS], FMH::MODEL_NAME[FMH::MODEL_KEY::ARTIST], artist, FMH::MODEL_NAME[FMH::MODEL_KEY::ALBUM], album, FMH::MODEL_NAME[orderBy], SLANG[order]);
 
     return this->getDBData(queryTxt);
 }
@@ -444,7 +464,7 @@ FMH::MODEL_LIST CollectionDB::getAlbumTracks(const QString &album, const QString
 FMH::MODEL_LIST CollectionDB::getArtistTracks(const QString &artist, const FMH::MODEL_KEY &orderBy, const BAE::W &order)
 {
     const auto queryTxt =
-            QString("SELECT * FROM %1 WHERE %2 = \"%3\" ORDER by %4 %5, %6 %5").arg(TABLEMAP[TABLE::TRACKS], FMH::MODEL_NAME[FMH::MODEL_KEY::ARTIST], artist, FMH::MODEL_NAME[orderBy], SLANG[order], FMH::MODEL_NAME[FMH::MODEL_KEY::TRACK]);
+        QString("SELECT * FROM %1 WHERE %2 = \"%3\" ORDER by %4 %5, %6 %5").arg(TABLEMAP[TABLE::TRACKS], FMH::MODEL_NAME[FMH::MODEL_KEY::ARTIST], artist, FMH::MODEL_NAME[orderBy], SLANG[order], FMH::MODEL_NAME[FMH::MODEL_KEY::TRACK]);
 
     return this->getDBData(queryTxt);
 }
@@ -470,11 +490,11 @@ FMH::MODEL_LIST CollectionDB::getSearchedTracks(const FMH::MODEL_KEY &where, con
         queryTxt = QString("SELECT t.* FROM %1 t inner join albums al on al.album = t.album and t.artist = al.artist WHERE %2 = \"%3\"").arg(TABLEMAP[TABLE::TRACKS], FMH::MODEL_NAME[where], search);
     else if (where == FMH::MODEL_KEY::WIKI)
 
-        queryTxt = QString("SELECT DISTINCT t.* FROM %1 t INNER JOIN %2 al ON t.%3 = al.%3 INNER JOIN %4 ar ON t.%5 = ar.%5 WHERE al.%6 LIKE \"%%7%\" OR ar.%6 LIKE \"%%7%\" COLLATE NOCASE")
-                .arg(TABLEMAP[TABLE::TRACKS], TABLEMAP[TABLE::ALBUMS], FMH::MODEL_NAME[FMH::MODEL_KEY::ALBUM], TABLEMAP[TABLE::ARTISTS], FMH::MODEL_NAME[FMH::MODEL_KEY::ARTIST], FMH::MODEL_NAME[where], search);
+    queryTxt = QString("SELECT DISTINCT t.* FROM %1 t INNER JOIN %2 al ON t.%3 = al.%3 INNER JOIN %4 ar ON t.%5 = ar.%5 WHERE al.%6 LIKE \"%%7%\" OR ar.%6 LIKE \"%%7%\" COLLATE NOCASE")
+                   .arg(TABLEMAP[TABLE::TRACKS], TABLEMAP[TABLE::ALBUMS], FMH::MODEL_NAME[FMH::MODEL_KEY::ALBUM], TABLEMAP[TABLE::ARTISTS], FMH::MODEL_NAME[FMH::MODEL_KEY::ARTIST], FMH::MODEL_NAME[where], search);
     else
         queryTxt = QString("SELECT t.* FROM %1 t inner join albums al on al.album = t.album and t.artist = al.artist WHERE t.%2 LIKE \"%%3%\" ORDER BY strftime(\"%s\", t.addDate) desc LIMIT 1000")
-                .arg(TABLEMAP[TABLE::TRACKS], FMH::MODEL_NAME[where], search);
+                       .arg(TABLEMAP[TABLE::TRACKS], FMH::MODEL_NAME[where], search);
 
     return this->getDBData(queryTxt);
 }
@@ -489,7 +509,7 @@ FMH::MODEL_LIST CollectionDB::getRecentTracks(const int &limit, const FMH::MODEL
 FMH::MODEL_LIST CollectionDB::getMostPlayedTracks(const int &greaterThan, const int &limit, const FMH::MODEL_KEY &orderBy, const BAE::W &order)
 {
     auto queryTxt =
-            QString("SELECT * FROM %1 WHERE %2 > %3 ORDER BY %4 %5 LIMIT %6").arg(TABLEMAP[TABLE::TRACKS], FMH::MODEL_NAME[FMH::MODEL_KEY::COUNT], QString::number(greaterThan), FMH::MODEL_NAME[orderBy], SLANG[order], QString::number(limit));
+        QString("SELECT * FROM %1 WHERE %2 > %3 ORDER BY %4 %5 LIMIT %6").arg(TABLEMAP[TABLE::TRACKS], FMH::MODEL_NAME[FMH::MODEL_KEY::COUNT], QString::number(greaterThan), FMH::MODEL_NAME[orderBy], SLANG[order], QString::number(limit));
 
     return this->getDBData(queryTxt);
 }
@@ -564,7 +584,7 @@ void CollectionDB::removeMissingTracks()
     auto tracks = this->getDBData("select url from tracks");
 
     for (auto track : tracks)
-        if (!FMH::fileExists(track[FMH::MODEL_KEY::URL]))
+        if (!FMH::fileExists(QUrl(track[FMH::MODEL_KEY::URL])))
             this->removeTrack(track[FMH::MODEL_KEY::URL]);
 }
 
@@ -599,7 +619,7 @@ bool CollectionDB::cleanAlbums()
 {
     //    delete from albums where (album, artist) in (select a.album, a.artist from albums a except select distinct album, artist from tracks);
     const auto queryTxt = QString("DELETE FROM %1 WHERE (%2, %3) IN (SELECT %2, %3 FROM %1 EXCEPT SELECT DISTINCT %2, %3  FROM %4)")
-            .arg(TABLEMAP[TABLE::ALBUMS], FMH::MODEL_NAME[FMH::MODEL_KEY::ALBUM], FMH::MODEL_NAME[FMH::MODEL_KEY::ARTIST], TABLEMAP[TABLE::TRACKS]);
+                              .arg(TABLEMAP[TABLE::ALBUMS], FMH::MODEL_NAME[FMH::MODEL_KEY::ALBUM], FMH::MODEL_NAME[FMH::MODEL_KEY::ARTIST], TABLEMAP[TABLE::TRACKS]);
     qDebug() << queryTxt;
     auto query = this->getQuery(queryTxt);
     Q_EMIT albumsCleaned(query.numRowsAffected());
