@@ -5,10 +5,9 @@
 #include "NextCloud/nextmusic.h"
 #include "abstractmusicprovider.h"
 
-#include <MauiKit3/Accounts/mauiaccounts.h>
+#include <MauiKit4/Accounts/mauiaccounts.h>
 
-Cloud::Cloud(QObject *parent)
-    : MauiList(parent)
+Cloud::Cloud(QObject *parent) : MauiList(parent)
     , provider(new NextMusic(this))
 {
     connect(MauiAccounts::instance(), &MauiAccounts::currentAccountChanged, [this](QVariantMap account) {
